Struct stdcli::term::Select [] [src]

pub struct Select { /* fields omitted */ }

Renders a selection menu.

Methods

impl Select
[src]

[src]

Creates the prompt with a specific text.

[src]

Sets the clear behavior of the menu.

The default is to clear the menu.

[src]

Sets a default for the menu

[src]

Add a single item to the selector.

[src]

Adds multiple items to the selector.

[src]

Enables user interaction and returns the result.

If the user confirms the result is true, false otherwise. The dialog is rendered on stderr.

[src]

Like interact but allows a specific terminal to be set.